You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@httpd.apache.org by wr...@apache.org on 2005/03/31 21:05:12 UTC

svn commit: r159627 - httpd/httpd/trunk/support/win32/ApacheMonitor.c

Author: wrowe
Date: Thu Mar 31 11:05:11 2005
New Revision: 159627

URL: http://svn.apache.org/viewcvs?view=rev&rev=159627
Log:

  httpd and Apache are both anticipated now.

Modified:
    httpd/httpd/trunk/support/win32/ApacheMonitor.c

Modified: httpd/httpd/trunk/support/win32/ApacheMonitor.c
URL: http://svn.apache.org/viewcvs/httpd/httpd/trunk/support/win32/ApacheMonitor.c?view=diff&r1=159626&r2=159627
==============================================================================
--- httpd/httpd/trunk/support/win32/ApacheMonitor.c (original)
+++ httpd/httpd/trunk/support/win32/ApacheMonitor.c Thu Mar 31 11:05:11 2005
@@ -997,8 +997,9 @@
                     {
                         lstrcpy(szBuf, szImagePath);
                         CharLower(szBuf);
-                        /* the service name could be Apache*.exe */
-                        if ((strstr(szBuf, "\\apache") != NULL)
+                        /* the service name could be httpd*.exe or Apache*.exe */
+                        if (((strstr(szBuf, "\\apache") != NULL)
+                             || (strstr(szBuf, "\\httpd") != NULL))
                                 && strstr(szBuf, ".exe") 
                                 && (strstr(szBuf, "--ntservice") != NULL 
                                        || strstr(szBuf, "-k ") != NULL))